@@ -26,9 +26,7 @@ class ColumnConsistency
     public function __construct(
         protected int $columns_count = -1
     ) {
-        if ($this->columns_count < -1) {
-            throw InvalidArgument::dueToInvalidColumnCount($this->columns_count, __METHOD__);
-        }
+        $this->columns_count >= -1 || throw InvalidArgument::dueToInvalidColumnCount($this->columns_count, __METHOD__);
     }
 
     /**
