@@ -17,8 +17,14 @@ use InvalidArgumentException;
 use PHPUnit\Framework\Attributes\DataProvider;
 use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\TestCase;
+
 use function stream_get_filters;
 
+/**
+ * DEPRECATION WARNING! This class will be removed in the next major point release.
+ *
+ * @deprecated since version 9.10.0
+ */
 #[Group('filter')]
 final class EncloseFieldTest extends TestCase
 {
@@ -36,7 +42,7 @@ final class EncloseFieldTest extends TestCase
 
     public function testEncloseAll(): void
     {
-        $csv = Writer::createFromString('');
+        $csv = Writer::fromString('');
         $csv->setDelimiter('|');
         EncloseField::addTo($csv, "\t\x1f");
         self::assertContains(EncloseField::getFiltername(), stream_get_filters());
@@ -82,7 +88,7 @@ CSV;
     {
         $this->expectException(InvalidArgumentException::class);
 
-        $csv = Writer::createFromString('');
+        $csv = Writer::fromString('');
         $csv->setDelimiter('|');
         EncloseField::addTo($csv, 'foo');
     }
