@@ -35,7 +35,7 @@ final class JsonConverterTest extends TestCase
     #[Test]
     public function it_will_convert_a_tabular_data_reader_into_a_json(): void
     {
-        $csv = Reader::createFromPath(__DIR__.'/../test_files/prenoms.csv');
+        $csv = Reader::from(__DIR__.'/../test_files/prenoms.csv');
         $csv->setDelimiter(';');
         $csv->setHeaderOffset(0);
 
@@ -73,6 +73,7 @@ final class JsonConverterTest extends TestCase
                 ->removeFlags(0)
                 ->depth(512)
                 ->chunkSize(500)
+                ->format(JsonFormat::Standard)
         );
     }
 
@@ -133,7 +134,7 @@ final class JsonConverterTest extends TestCase
             ->withoutHexQuot()
             ->depth(24);
 
-        self::assertEquals($usingJsonFlags, $usingMethodFlags);
+        self::assertSame($usingJsonFlags->encode([['foo' => 'bar']]), $usingMethodFlags->encode([['foo' => 'bar']]));
     }
 
     #[Test]
@@ -203,4 +204,93 @@ final class JsonConverterTest extends TestCase
         self::assertSame(2, $converter->indentSize);
         self::assertFalse($converter->usePrettyPrint());
     }
+
+    #[Test]
+    public function it_can_generate_an_empty_ldjson_file(): void
+    {
+        $converter = (new JsonConverter())->format(JsonFormat::NdJson);
+
+        self::assertSame('', $converter->encode([]));
+    }
+
+    #[Test]
+    public function it_can_generate_ldjson_file_with_data(): void
+    {
+        $converter = (new JsonConverter())->format(JsonFormat::NdJson);
+
+        self::assertSame(
+            '{"foo":"bar"}'."\n".'{"foo":"bar"}'."\n".'{"foo":"bar"}'."\n",
+            $converter->encode([
+                ['foo' => 'bar'],
+                ['foo' => 'bar'],
+                ['foo' => 'bar'],
+            ])
+        );
+    }
+
+    #[Test]
+    public function it_can_tell_which_fornat_it_is_using(): void
+    {
+        $converter = new JsonConverter();
+        $newConverter = $converter->format(JsonFormat::NdJson);
+
+        self::assertSame(JsonFormat::Standard, $converter->format);
+        self::assertSame(JsonFormat::NdJson, $newConverter->format);
+    }
+
+    #[Test]
+    public function it_can_force_generate_ldjson_with_list_headers(): void
+    {
+        $csv = Reader::from(__DIR__.'/../test_files/prenoms.csv')
+            ->setDelimiter(';')
+            ->setHeaderOffset(0);
+
+        CharsetConverter::addTo($csv, 'iso-8859-15', 'utf-8');
+
+        $data = (new JsonConverter())
+            ->format(JsonFormat::NdJsonHeader)
+            ->encode(
+                records: $csv->slice(0, 3),
+                header: $csv->getHeader(),
+            );
+
+        self::assertStringContainsString('["prenoms","nombre","sexe","annee"]', $data);
+    }
+
+    #[Test]
+    public function it_can_force_generate_ldjson_without_headers(): void
+    {
+        $csv = Reader::from(__DIR__.'/../test_files/prenoms.csv')
+            ->setDelimiter(';')
+            ->setHeaderOffset(0);
+
+        CharsetConverter::addTo($csv, 'iso-8859-15', 'utf-8');
+
+        $data = (new JsonConverter())
+            ->format(JsonFormat::NdJsonHeaderLess)
+            ->encode(
+                records: $csv->slice(0, 3),
+                header: $csv->getHeader(),
+            );
+
+        self::assertStringNotContainsString('["prenoms","nombre","sexe","annee"]', $data);
+    }
+
+    #[Test]
+    public function it_fails_generating_the_ldjson_if_no_header_is_provided(): void
+    {
+        $this->expectException(InvalidArgument::class);
+
+        $csv = Reader::from(__DIR__.'/../test_files/prenoms.csv')
+            ->setDelimiter(';')
+            ->setHeaderOffset(0);
+
+        CharsetConverter::addTo($csv, 'iso-8859-15', 'utf-8');
+
+        $this->expectException(InvalidArgument::class);
+
+        (new JsonConverter())
+            ->format(JsonFormat::NdJsonHeader)
+            ->encode(records: $csv->slice(0, 3));
+    }
 }
